# EmXPS - Miscellaneous Explanation Methods

[![PyPI pyversions](https://img.shields.io/pypi/pyversions/emxps.svg)](https://pypi.python.org/pypi/emxps/)
[![GitHub license](https://img.shields.io/github/license/emanuele-albini/emxps)](https://github.com/emanuele-albini/emxps/blob/master/LICENSE)
[![PyPI](https://badge.fury.io/py/emxps.svg)](https://pypi.python.org/pypi/emxps/)
[![Maintaner](https://img.shields.io/badge/maintainer-Emanuele-lightgrey)](https://www.emanuelealbini.com)
[![Tests](https://github.com/emanuele-albini/emxps/actions/workflows/tests.yml/badge.svg)](https://github.com/emanuele-albini/emxps/actions/workflows/tests.yml)
<!-- [![Release](https://github.com/emanuele-albini/emxps/actions/workflows/release.yml/badge.svg)](https://github.com/emanuele-albini/emxps/actions/workflows/release.yml) -->

This package contains various implementations of *feature importance* and *counterfactual explanations* (aka *actionable recourse*) methods for research purposes.

**Package under active development. Please use specific releases version from PyPi or conda for stable versions.**

## Installation

Using PIP:

```bash
pip install emxps
```

#### For developers

To use the package in editable mode use instead the following.

```bash
git clone https://github.com/emanuele-albini/emxps.git
pip install --editable emxps
```


## Documentation

See [here](https://emanuele-albini.github.io/emxps) for the complete documentation of the modules.
